pub struct DeduplicationCache { /* private fields */ }Expand description
Deduplication cache for K2K message processing.
Tracks recently-seen message IDs to prevent duplicate processing. Uses a bounded LRU-style eviction with TTL expiry.
Implementations
Sourceimpl DeduplicationCache
impl DeduplicationCache
Sourcepub fn new(config: DeduplicationConfig) -> Self
pub fn new(config: DeduplicationConfig) -> Self
Create a new deduplication cache.
Sourcepub fn is_duplicate(&mut self, idempotency_key: u64) -> bool
pub fn is_duplicate(&mut self, idempotency_key: u64) -> bool
Check if a message ID is a duplicate. If not, records it.
Returns true if this message was already seen (duplicate).
Returns false if this is the first time (not duplicate, now recorded).
Sourcepub fn was_seen(&self, idempotency_key: u64) -> bool
pub fn was_seen(&self, idempotency_key: u64) -> bool
Check if a key was seen without recording it.
Sourcepub fn metrics(&self) -> DeduplicationMetrics
pub fn metrics(&self) -> DeduplicationMetrics
Get deduplication metrics.