ShutdownGuard

Struct ShutdownGuard 

pub struct ShutdownGuard { /* private fields */ }
Guard returned by GracefulShutdown::install.

Holds the background signal-listening task. Call wait to block until the signal fires and the grace period elapses (or until the task is aborted on drop).

Implementations

Source

impl ShutdownGuard

pub fn signal(&self) -> ShutdownSignal

Get a ShutdownSignal from this guard.

pub async fn wait(self)

Wait for the signal listener task to complete.

This resolves after a signal has been received and the grace period has elapsed. If no signal is ever received this future never completes (you can select! it against your main workload).

pub fn cancel(self)

Cancel the signal listener without waiting.