pub struct ShutdownSignal { /* private fields */ }Expand description
A lightweight, clone-able handle for checking or awaiting shutdown.
Multiple kernels and background tasks can each hold a clone. Checking
is_shutdown_requested is a
single atomic load and therefore safe to call on hot paths.
Implementations
Sourceimpl ShutdownSignal
impl ShutdownSignal
Sourcepub fn is_shutdown_requested(&self) -> bool
pub fn is_shutdown_requested(&self) -> bool
Returns true once shutdown has been requested.
This is a single atomic load and can be called on hot paths without any overhead.