pub struct CloudWatchSink { /* private fields */ }Expand description
CloudWatch Logs sink for AWS-native audit logging.
When the cloudwatch feature is enabled, this sink uses the AWS SDK to
upload audit events to CloudWatch Logs via the PutLogEvents API with
automatic batching and retry on throttling.
When the cloudwatch feature is not enabled, this acts as a stub that
buffers events but drops them with a warning on flush.
Implementations
Sourceimpl CloudWatchSink
impl CloudWatchSink
Sourcepub fn new(config: CloudWatchConfig) -> Self
pub fn new(config: CloudWatchConfig) -> Self
Create a new CloudWatch Logs sink (stub, without cloudwatch feature).
Sourcepub fn config(&self) -> &CloudWatchConfig
pub fn config(&self) -> &CloudWatchConfig
Get the configuration.
Sourcepub fn buffer_size(&self) -> usize
pub fn buffer_size(&self) -> usize
Get the current buffer size.